We noticed your account was newly added by your domain administrator.

Hi {{user_name}}, This is a budget usage alert sent from the workspace '{{workspace_name}}'. • Budget Name: {{budget_name}} • Budget Target: {{budget_target}} • Budget Amount: {{budget_amount}} ({{budget_cycle}}) • Actual Cost: {{actual_cost}} {{currency}} ({{usage_rate}}%) • Alert Date: {{today_date}}
View Budget Details
This email is sent to budget managers. If you no longer wish to receive these notifications, please update the budget manager settings or contact your workspace owners. Thank you, SpaceONE
Homepage | Blog | Help Center Copyright 2024 © MEGAZONE CLOUD Corp. All Right Reserved.